##  How to Model Relations Between Objectives and Other Fact Sheets
The image below shows the relations explorer view in an exemplary objective fact sheet. This shows the objective is linked to other fact sheet types such as organization, business capability, initiative, and platform.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751328c7a4410149b71f07444c8a261_LowRes.png)
